==> jc-1.4.0.tar.gz: javax/swing/Popup__24JWindowPopup.h <==
// class javax.swing.Popup$JWindowPopup

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 233bc5f46f80075e javax_swing_Popup
// @dep_class 9f32fd703f54eef8 javax_swing_Popup__24JWindowPopup

// header file dependencies
// @dep_header javax_swing_Popup

#include "javax/swing/Popup.h"

#ifndef _JC_javax_swing_Popup__24JWindowPopup_H_
#define _JC_javax_swing_Popup__24JWindowPopup_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JWindow$object;

// Typedefs
typedef struct _jc_javax_swing_Popup__24JWindowPopup$sub_refs	_jc_javax_swing_Popup__24JWindowPopup$sub_refs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs	_jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$refs	_jc_javax_swing_Popup__24JWindowPopup$refs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$nonrefs	_jc_javax_swing_Popup__24JWindowPopup$nonrefs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$object	_jc_javax_swing_Popup__24JWindowPopup$object;

typedef const struct _jc_javax_swing_Popup__24JWindowPopup$vmethods	_jc_javax_swing_Popup__24JWindowPopup$vmethods;
typedef const struct _jc_javax_swing_Popup__24JWindowPopup$vtable	_jc_javax_swing_Popup__24JWindowPopup$vtable;
typedef const struct _jc_javax_swing_Popup__24JWindowPopup$vtype	_jc_javax_swing_Popup__24JWindowPopup$vtype;

// Constructors
extern void _jc_javax_swing_Popup__24JWindowPopup$method$_init$b51abd882b49de59(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint);

// Virtual methods
extern void _jc_javax_swing_Popup__24JWindowPopup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *);
extern void _jc_javax_swing_Popup__24JWindowPopup$method$show$8844e066fe447d0e(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Popup__24JWindowPopup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_Popup__24JWindowPopup$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_javax_swing_Popup__24JWindowPopup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *);
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *);
};

// Vtable
struct _jc_javax_swing_Popup__24JWindowPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Popup$vmethods	javax_swing_Popup;
	_jc_javax_swing_Popup__24JWindowPopup$vmethods	javax_swing_Popup__24JWindowPopup;
};

// Vtype
struct _jc_javax_swing_Popup__24JWindowPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_Popup__24JWindowPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Popup__24JWindowPopup$sub_refs {
	struct _jc_javax_swing_JWindow$object	*window;
};

// Reference instance fields (object)
struct _jc_javax_swing_Popup__24JWindowPopup$refs {
    _jc_javax_swing_Popup__24JWindowPopup$sub_refs	javax_swing_Popup__24JWindowPopup;
    _jc_javax_swing_Popup$sub_refs	javax_swing_Popup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Popup__24JWindowPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Popup$sub_nonrefs	javax_swing_Popup;
    _jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs	javax_swing_Popup__24JWindowPopup;
};

// Object instance structure
struct _jc_javax_swing_Popup__24JWindowPopup$object {
	_jc_javax_swing_Popup__24JWindowPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Popup__24JWindowPopup$vtype	*vtype;
	_jc_javax_swing_Popup__24JWindowPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Popup__24JWindowPopup$vtype _jc_javax_swing_Popup__24JWindowPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Popup__24JWindowPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Popup__24JWindowPopup$class_object;

#endif	/* _JC_javax_swing_Popup__24JWindowPopup_H_ */

==> jc-1.4.6.tar.gz: javax/swing/Popup__24JWindowPopup.h <==
// class javax.swing.Popup$JWindowPopup

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 233bc5f46f80075e javax_swing_Popup
// @dep_class 9f32fd703f54eef8 javax_swing_Popup__24JWindowPopup

// header file dependencies
// @dep_header javax_swing_Popup

#include "javax/swing/Popup.h"

#ifndef _JC_javax_swing_Popup__24JWindowPopup_H_
#define _JC_javax_swing_Popup__24JWindowPopup_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JWindow$object;

// Typedefs
typedef struct _jc_javax_swing_Popup__24JWindowPopup$sub_refs	_jc_javax_swing_Popup__24JWindowPopup$sub_refs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs	_jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$refs	_jc_javax_swing_Popup__24JWindowPopup$refs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$nonrefs	_jc_javax_swing_Popup__24JWindowPopup$nonrefs;
typedef struct _jc_javax_swing_Popup__24JWindowPopup$object	_jc_javax_swing_Popup__24JWindowPopup$object;

typedef const struct _jc_javax_swing_Popup__24JWindowPopup$vmethods	_jc_javax_swing_Popup__24JWindowPopup$vmethods;
typedef const struct _jc_javax_swing_Popup__24JWindowPopup$vtable	_jc_javax_swing_Popup__24JWindowPopup$vtable;
typedef const struct _jc_javax_swing_Popup__24JWindowPopup$vtype	_jc_javax_swing_Popup__24JWindowPopup$vtype;

// Constructors
extern void _jc_javax_swing_Popup__24JWindowPopup$method$_init$b51abd882b49de59(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Component$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_Popup__24JWindowPopup$method$hide$048a3beb9ae7da95(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_Popup__24JWindowPopup$method$show$8844e066fe447d0e(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_Popup__24JWindowPopup$method_info$hide$048a3beb9ae7da95;
extern _jc_method _jc_javax_swing_Popup__24JWindowPopup$method_info$show$8844e066fe447d0e;

// Virtual methods structure
struct _jc_javax_swing_Popup__24JWindowPopup$vmethods {
	void	(*hide$048a3beb9ae7da95)(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *) _JC_JCNI_ATTR;
	void	(*show$8844e066fe447d0e)(_jc_env *, struct _jc_javax_swing_Popup__24JWindowPopup$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_Popup__24JWindowPopup$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_Popup$vmethods	javax_swing_Popup;
	_jc_javax_swing_Popup__24JWindowPopup$vmethods	javax_swing_Popup__24JWindowPopup;
};

// Vtype
struct _jc_javax_swing_Popup__24JWindowPopup$vtype {
	_jc_type			type;
	_jc_javax_swing_Popup__24JWindowPopup$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_Popup__24JWindowPopup$sub_refs {
	struct _jc_javax_swing_JWindow$object	*window;
};

// Reference instance fields (object)
struct _jc_javax_swing_Popup__24JWindowPopup$refs {
    _jc_javax_swing_Popup__24JWindowPopup$sub_refs	javax_swing_Popup__24JWindowPopup;
    _jc_javax_swing_Popup$sub_refs	javax_swing_Popup;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_Popup__24JWindowPopup$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_Popup$sub_nonrefs	javax_swing_Popup;
    _jc_javax_swing_Popup__24JWindowPopup$sub_nonrefs	javax_swing_Popup__24JWindowPopup;
};

// Object instance structure
struct _jc_javax_swing_Popup__24JWindowPopup$object {
	_jc_javax_swing_Popup__24JWindowPopup$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_Popup__24JWindowPopup$vtype	*vtype;
	_jc_javax_swing_Popup__24JWindowPopup$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_Popup__24JWindowPopup$vtype _jc_javax_swing_Popup__24JWindowPopup$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_Popup__24JWindowPopup, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_Popup__24JWindowPopup$class_object;

#endif	/* _JC_javax_swing_Popup__24JWindowPopup_H_ */
